# 2021-09-07 - Investment Pool

> ⚠️ **DEPRECATED: do not use** ⚠️
>
> This factory and associated Pools have been deprecated. A version of Managed Pools will soon be released, providing a migration path for existing Pools.

## Useful Files

- [Ethereum mainnet addresses](./output/mainnet.json)
- [Polygon mainnet address](./output/polygon.json)
- [Arbitrum mainnet address](./output/arbitrum.json)
- [Goerli testnet addresses](./output/goerli.json)
- [`InvestmentPoolFactory` artifact](./artifact/InvestmentPoolFactory.json)
